@@ -27,12 +27,14 @@ public enum Key {
   RelaySources(SourceType[].class),
   BridgeSources(SourceType[].class),
   ExitlistSources(SourceType[].class),
+  OnionPerfSources(SourceType[].class),
   RelayCacheOrigins(String[].class),
   RelayLocalOrigins(Path.class),
   RelaySyncOrigins(URL[].class),
   BridgeSyncOrigins(URL[].class),
   BridgeLocalOrigins(Path.class),
   ExitlistSyncOrigins(URL[].class),
+  OnionPerfSyncOrigins(URL[].class),
   BridgedescsActivated(Boolean.class),
   BridgedescsOffsetMinutes(Integer.class),
   BridgedescsPeriodMinutes(Integer.class),
@@ -42,9 +44,9 @@ public enum Key {
   RelaydescsActivated(Boolean.class),
   RelaydescsOffsetMinutes(Integer.class),
   RelaydescsPeriodMinutes(Integer.class),
-  TorperfActivated(Boolean.class),
-  TorperfOffsetMinutes(Integer.class),
-  TorperfPeriodMinutes(Integer.class),
+  OnionPerfActivated(Boolean.class),
+  OnionPerfOffsetMinutes(Integer.class),
+  OnionPerfPeriodMinutes(Integer.class),
   UpdateindexActivated(Boolean.class),
   UpdateindexOffsetMinutes(Integer.class),
   UpdateindexPeriodMinutes(Integer.class),
@@ -56,8 +58,7 @@ public enum Key {
   KeepDirectoryArchiveImportHistory(Boolean.class),
   ReplaceIpAddressesWithHashes(Boolean.class),
   BridgeDescriptorMappingsLimit(Integer.class),
-  TorperfFilesLines(String[].class),
-  TorperfHosts(String[][].class);
+  OnionPerfHosts(URL[].class);
 
   private Class clazz;
   private static Set<String> keys;
