@@ -4,7 +4,6 @@
 package org.torproject.collector.relaydescs;
 
 import org.torproject.descriptor.Descriptor;
-import org.torproject.descriptor.DescriptorFile;
 import org.torproject.descriptor.DescriptorReader;
 import org.torproject.descriptor.DescriptorSourceFactory;
 import org.torproject.descriptor.DirSourceEntry;
@@ -49,7 +48,7 @@ public class ReferenceChecker {
 
   private long currentTimeMillis;
 
-  private SortedSet<Reference> references = new TreeSet<Reference>();
+  private SortedSet<Reference> references = new TreeSet<>();
 
   private static DateFormat dateTimeFormat;
 
@@ -167,38 +166,36 @@ public class ReferenceChecker {
   private void readNewDescriptors() {
     DescriptorReader descriptorReader =
         DescriptorSourceFactory.createDescriptorReader();
-    descriptorReader.addDirectory(this.descriptorsDir);
-    descriptorReader.setExcludeFiles(this.historyFile);
-    Iterator<DescriptorFile> descriptorFiles =
-        descriptorReader.readDescriptors();
-    while (descriptorFiles.hasNext()) {
-      DescriptorFile descriptorFile = descriptorFiles.next();
-      for (Descriptor descriptor : descriptorFile.getDescriptors()) {
-        if (descriptor instanceof RelayNetworkStatusConsensus) {
-          RelayNetworkStatusConsensus consensus =
-              (RelayNetworkStatusConsensus) descriptor;
-          String consensusFlavor = consensus.getConsensusFlavor();
-          if (consensusFlavor == null) {
-            this.readRelayNetworkStatusConsensusUnflavored(consensus);
-          } else if (consensusFlavor.equals("microdesc")) {
-            this.readRelayNetworkStatusConsensusMicrodesc(consensus);
-          } else {
-            /* Ignore unknown consensus flavors. */
-          }
-        } else if (descriptor instanceof RelayNetworkStatusVote) {
-          this.readRelayNetworkStatusVote(
-              (RelayNetworkStatusVote) descriptor);
-        } else if (descriptor instanceof ServerDescriptor) {
-          this.readServerDescriptor((ServerDescriptor) descriptor);
-        } else if (descriptor instanceof ExtraInfoDescriptor) {
-          this.readExtraInfoDescriptor((ExtraInfoDescriptor) descriptor);
-        } else if (descriptor instanceof Microdescriptor) {
-          readMicrodescriptor((Microdescriptor) descriptor);
+    descriptorReader.setHistoryFile(this.historyFile);
+    Iterator<Descriptor> descriptors
+        = descriptorReader.readDescriptors(this.descriptorsDir).iterator();
+    while (descriptors.hasNext()) {
+      Descriptor descriptor = descriptors.next();
+      if (descriptor instanceof RelayNetworkStatusConsensus) {
+        RelayNetworkStatusConsensus consensus =
+            (RelayNetworkStatusConsensus) descriptor;
+        String consensusFlavor = consensus.getConsensusFlavor();
+        if (consensusFlavor == null) {
+          this.readRelayNetworkStatusConsensusUnflavored(consensus);
+        } else if (consensusFlavor.equals("microdesc")) {
+          this.readRelayNetworkStatusConsensusMicrodesc(consensus);
         } else {
-          /* Ignore unknown descriptors. */
+          /* Ignore unknown consensus flavors. */
         }
+      } else if (descriptor instanceof RelayNetworkStatusVote) {
+        this.readRelayNetworkStatusVote(
+            (RelayNetworkStatusVote) descriptor);
+      } else if (descriptor instanceof ServerDescriptor) {
+        this.readServerDescriptor((ServerDescriptor) descriptor);
+      } else if (descriptor instanceof ExtraInfoDescriptor) {
+        this.readExtraInfoDescriptor((ExtraInfoDescriptor) descriptor);
+      } else if (descriptor instanceof Microdescriptor) {
+        readMicrodescriptor((Microdescriptor) descriptor);
+      } else {
+        /* Ignore unknown descriptors. */
       }
     }
+    descriptorReader.saveHistoryFile(this.historyFile);
   }
 
   private void readRelayNetworkStatusConsensusUnflavored(
@@ -237,7 +234,7 @@ public class ReferenceChecker {
         / ((double) consensus.getStatusEntries().size());
     for (NetworkStatusEntry entry :
         consensus.getStatusEntries().values()) {
-      for (String digest : entry.getMicrodescriptorDigests()) {
+      for (String digest : entry.getMicrodescriptorDigestsSha256Base64()) {
         this.addReference(referencing, String.format("D-%s", digest),
             entryWeight, entry.getPublishedMillis() + THREE_HOURS);
       }
@@ -258,23 +255,24 @@ public class ReferenceChecker {
   }
 
   private void readServerDescriptor(ServerDescriptor serverDescriptor) {
-    String referenced = serverDescriptor.getExtraInfoDigest() == null ? ""
-        : String.format("E-%s", serverDescriptor.getExtraInfoDigest());
+    String referenced = serverDescriptor.getExtraInfoDigestSha1Hex() == null
+        ? "" : String.format("E-%s",
+        serverDescriptor.getExtraInfoDigestSha1Hex());
     this.addReference(String.format("S-%s",
-        serverDescriptor.getServerDescriptorDigest()), referenced, 0.01,
+        serverDescriptor.getDigestSha1Hex()), referenced, 0.01,
         serverDescriptor.getPublishedMillis() + SIX_HOURS);
   }
 
   private void readExtraInfoDescriptor(
       ExtraInfoDescriptor extraInfoDescriptor) {
     this.addReference(String.format("E-%s",
-        extraInfoDescriptor.getExtraInfoDigest()), "", 0.005,
+        extraInfoDescriptor.getDigestSha1Hex()), "", 0.005,
         extraInfoDescriptor.getPublishedMillis() + SIX_HOURS);
   }
 
   private void readMicrodescriptor(Microdescriptor microdesc) {
     this.addReference(
-        String.format("D-%s", microdesc.getMicrodescriptorDigest()), "",
+        String.format("D-%s", microdesc.getDigestSha256Base64()), "",
         0.0, this.currentTimeMillis + THIRTY_DAYS);
   }
 
@@ -285,7 +283,7 @@ public class ReferenceChecker {
   }
 
   private void dropStaleReferences() {
-    SortedSet<Reference> recentReferences = new TreeSet<Reference>();
+    SortedSet<Reference> recentReferences = new TreeSet<>();
     for (Reference reference : this.references) {
       if (this.currentTimeMillis <= reference.expiresAfterMillis) {
         recentReferences.add(reference);
@@ -295,12 +293,12 @@ public class ReferenceChecker {
   }
 
   private void checkReferences() {
-    Set<String> knownDescriptors = new HashSet<String>();
+    Set<String> knownDescriptors = new HashSet<>();
     for (Reference reference : this.references) {
       knownDescriptors.add(reference.referencing);
     }
     double totalMissingDescriptorsWeight = 0.0;
-    Set<String> missingDescriptors = new TreeSet<String>();
+    Set<String> missingDescriptors = new TreeSet<>();
     StringBuilder sb = new StringBuilder("Missing referenced "
         + "descriptors:");
     for (Reference reference : this.references) {
